#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-kat
version:              0.0.3
visibility:           public
id:                   tasty-kat-0.0.3-GTtyU95JAUDFCyBEPotpkC
key:                  tasty-kat-0.0.3-GTtyU95JAUDFCyBEPotpkC
license:              MIT
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/tasty-kat
synopsis:             Known Answer Tests (KAT) framework for tasty
description:
    Tests running from simple KATs file (different formats/helper supported)

category:             tasty-kat
abi:                  79dc6b67e9e73446c41332abd20be8e2
exposed:              True
exposed-modules:      Test.Tasty.KAT Test.Tasty.KAT.FileLoader
hidden-modules:       Test.Tasty.KAT.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-kat-0.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-kat-0.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-kat-0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-kat
hs-libraries:         HStasty-kat-0.0.3-GTtyU95JAUDFCyBEPotpkC
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    tasty-1.5.3-7W3ODf0SeIu7bHDUebRuXp

haddock-interfaces:   /usr/share/doc/haskell-tasty-kat/html/tasty-kat.haddock
haddock-html:         /usr/share/doc/haskell-tasty-kat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

